\name{SIMMS-package}
\Rdversion{0.0.1}
\alias{SIMMS-package}
\alias{SIMMS}
\docType{package}
\title{SIMMS - Subnetwork Integration for Multi-Modal Signatures}
\description{Algorithms to create prognostic biomarkers using biological networks}
\details{
\tabular{ll}{
Package: \tab SIMMS\cr
Type: \tab Package\cr
Version: \tab 0.0.1\cr
Date: \tab 2012-06-11\cr
License: \tab GPL-2\cr
LazyLoad: \tab yes\cr
}
}
\author{
Syed Haider, Michal Grzadkowski & Paul C. Boutros
}
\keyword{ package }
\examples{
options("warn" = -1);

# get data directory 
data.directory <- get.program.defaults(networks.database = "test")[["test.data.dir"]];

# initialise params
output.directory <- ".";
data.types <- c("mRNA");
feature.selection.datasets <- c("Breastdata1");
training.datasets <- c("Breastdata1");
validation.datasets <- c("Breastdata2");
feature.selection.p.thresholds <- c(0.5);
feature.selection.p.threshold <- 0.5;
top.n.features <- 5;

# compute network HRs for all the subnet features
derive.network.features(
  data.directory = data.directory,
  output.directory = output.directory,
  data.types = data.types,
  feature.selection.datasets = feature.selection.datasets,
  feature.selection.p.thresholds = feature.selection.p.thresholds,
  networks.database = "test"
  );

# preparing training and validation datasets.
# Normalisation & patientwise subnet feature scores
prepare.training.validation.datasets(
  data.directory = data.directory,
  output.directory = output.directory,
  data.types = data.types,
  feature.selection.datasets = feature.selection.datasets,
  datasets = unique(c(training.datasets, validation.datasets)),
  networks.database = "test"
  );

# fit survival model (feature selection using forward selection & backward elimination)
fit.survivalmodel(
  data.directory = data.directory,
  output.directory = output.directory,
  feature.selection.datasets = feature.selection.datasets,
  feature.selection.p.threshold = feature.selection.p.threshold,
  training.datasets = training.datasets,
  top.n.features = top.n.features
  );

# predict patient risk scores/groups using the betas generated by the fit
pred.survivalmodel(
  data.directory = data.directory,
  output.directory = output.directory,
  feature.selection.datasets = feature.selection.datasets,
  feature.selection.p.threshold = feature.selection.p.threshold,
  training.datasets = training.datasets,
  validation.datasets = validation.datasets,
  top.n.features = top.n.features
  );

# (optional) plot Kaplan-meier survival curves and perform senstivity analysis
if (FALSE){
  create.survivalplots(
    data.directory = data.directory,
    output.directory = output.directory,
    training.datasets = training.datasets,
    validation.datasets = validation.datasets,
    top.n.features = top.n.features,
    survtime.cutoffs = c(5),
    KM.plotting.fun = "create.KM.plot",
    resolution = 100
    );
  }
}
